.line-path {
    stroke-dasharray: 100 200;
    stroke-dashoffset: 100;
    animation: drawLine 500ms forwards;
    animation-delay: 100ms;
}

@keyframes drawLine {
    to {
        stroke-dasharray: 100 200;
        stroke-dashoffset: 0;
    }
}

.bar {
    transform: scaleY(0);
    transform-origin: bottom;
    transform-box: fill-box;
    animation: drawBar 500ms forwards;
    animation-delay: 100ms;
}

@keyframes drawBar {
    to {
        transform: scaleY(1);
    }
}

.fade-in {
    opacity: 0;
    animation: fadeIn 100ms forwards;
    animation-delay: 50ms;
}

@keyframes fadeIn {
    to {
        opacity: 1;
    }
}