body {
    font-family: 'Noto Serif', serif;
    font-size: 18px;
}

.grid-line {
    stroke-width: 2;
    stroke: rgba(96, 96, 96, 0.1);
}

.title {
    font-family: 'Noto Serif';
    font-style: normal;
    font-size: 1.7rem;
}

.svg-background {
    fill: transparent;
}

.sh {
    box-shadow: 5px 5px 0 hsl(0, 10%, 57%);
}

.blue {
    background-color: hsl(225, 53%, 52%);
}

.text-2-5xl {
    font-size: 1.7rem;
}

#sidebar-container {
    perspective: 600px;
    perspective-origin: bottom;
}

#sidebar {
    transform: scale(0.2) rotate(-360deg);
    animation: rotateIn 600ms ease-in forwards, rotateIn3 600ms ease-in forwards;
}

@keyframes rotateIn {
    to {
        transform: scale(1) rotate(0);
    }
}

@keyframes rotateIn3 {
    to {
        transform: scale(1) rotate3d(0, 1, 0, 25deg);
    }
}
