<line class="{{ classes|join:' ' }}" x1="{{ from_pos.x }}" y1="{{ from_pos.y }}" x2="{{ to_pos.x }}" y2="{{ to_pos.y }}" stroke="{{ stroke_color }}" stroke-width="{{ stroke_width }}" stroke-linecap="{{ stroke_linecap }}" pathLength="{{ path_length }}" />