{% csrf_token %}
<button 
id="{{ id }}"
class="py-3 px-4 cursor-pointer rounded
focus:underline outline-none w-full shadow dark:shadow-xl
bg-surface-2-light text-text-light dark:text-text-dark dark:bg-surface-dark"
{% if callback %}
hx-post="{% url callback.endpoint_name %}"
hx-trigger="click"
hx-swap="none"
hx-include="
{% for element in callback.inputs %}
    #{{ element }},
{% endfor %}
previous [name=csrfmiddlewaretoken]
"
hx-indicator="{{ callback.target_wrapper_ids }}"
{% endif %}
>
    {{ text }}
</button>