<svg
id="{{ id }}"
class="absolute chart"
xmlns="http://www.w3.org/2000/svg" 
viewBox="0 0 {{ width }} {{ height }}" 
width="{{ width }}" 
height="{{ height }}"
{% if swap_oob %}
    hx-swap-oob="true"
{% endif %}
>

    {% for element in elements %}{{ element|safe }}
    {% endfor %}
</svg>