<path class="{{ classes|join:' ' }}" d="{% for point in points %}{% if forloop.first %}M {% else %} L {% endif %}{{ point.x }} {{ point.y }}{% endfor %}" stroke-width="{{ stroke_width }}" stroke-linecap="{{ stroke_linecap }}" pathLength="{{ path_length }}" fill="{{ fill_color }}" />